"""
    Veeroute.LSS Stock

    Veeroute.LSS Stock API  # noqa: E501

    The version of the OpenAPI document: 3.8.168672
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import vrt_lss_stock
from vrt_lss_stock.model.trace_data import TraceData


class TestTraceData(unittest.TestCase):
    """TraceData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testTraceData(self):
        """Test TraceData"""
        # FIXME: construct object with mandatory attributes with example values
        # model = TraceData()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
