"""
    Veeroute.LSS Stock

    Veeroute.LSS Stock API  # noqa: E501

    The version of the OpenAPI document: 3.8.168672
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import vrt_lss_stock
from vrt_lss_stock.api.plan_api import PlanApi  # noqa: E501


class TestPlanApi(unittest.TestCase):
    """PlanApi unit test stubs"""

    def setUp(self):
        self.api = PlanApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_plan(self):
        """Test case for plan

        Planning.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
